CCL: CCL_ClTracer Struct Reference

CCL

Data Fields
CCL_ClTracer Struct Reference

`#include <ccl_cls.h>`

## Data Fields
int | tracer_type
double | prefac_lensing
double | chimax
double | chimin
int | has_rsd
int | has_magnification
int | has_intrinsic_alignment
SplPar * | spl_nz
SplPar * | spl_bz
SplPar * | spl_sz
SplPar * | spl_rf
SplPar * | spl_ba
SplPar * | spl_wL
SplPar * | spl_wM

## Detailed Description

ClTracer structure, used to contain everything that a Cl tracer could have, such as splines for various quantities and limits on the value of chi that this tracer deals with.

## Field Documentation

## ◆ chimax

double CCL_ClTracer::chimax

## ◆ chimin

double CCL_ClTracer::chimin

## ◆ has_intrinsic_alignment

int CCL_ClTracer::has_intrinsic_alignment

## ◆ has_magnification

int CCL_ClTracer::has_magnification

## ◆ has_rsd

int CCL_ClTracer::has_rsd

## ◆ prefac_lensing

double CCL_ClTracer::prefac_lensing

## ◆ spl_ba

SplPar* CCL_ClTracer::spl_ba

## ◆ spl_bz

SplPar* CCL_ClTracer::spl_bz

## ◆ spl_nz

SplPar* CCL_ClTracer::spl_nz

## ◆ spl_rf

SplPar* CCL_ClTracer::spl_rf

## ◆ spl_sz

SplPar* CCL_ClTracer::spl_sz

## ◆ spl_wL

SplPar* CCL_ClTracer::spl_wL

## ◆ spl_wM

SplPar* CCL_ClTracer::spl_wM

## ◆ tracer_type

int CCL_ClTracer::tracer_type

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_cls.h